# Custom Reports: Workspace Best Practice
### On this page
  * [What is the Workspace Best Practice Report?](https://help.sap.com/docs/leanix/ea/workspace-best-practice-report#what-is-the-workspace-best-practice-report?)
  * [How to Use It](https://help.sap.com/docs/leanix/ea/workspace-best-practice-report#how-to-use-it)
  * [How to Add the Workspace Best Practice Report to Your Workspace](https://help.sap.com/docs/leanix/ea/workspace-best-practice-report#how-to-add-the-workspace-best-practice-report-to-your-workspace)


Trusted partners create and share custom reports with others in the SAP LeanIX store. The workspace best practice report is one such example which outlines a set of standards for best practices, which can be used to assess and improve your workspace. By adhering to these standards, you can optimize data quality and enhance overall workspace performance.
